@@ -5,11 +5,9 @@ import json
 import re
 import martian
 from zope.component import getMultiAdapter
-from zope.component import getUtility
 from zope.publisher.publish import mapply
 from five import grok
 from zope.i18n import translate
-from z3c.appconfig.interfaces import IAppConfig
 from euphorie.client.navigation import getTreeData
 from euphorie.client.update import wasSurveyUpdated
 from euphorie.client.api.interfaces import IClientAPISkinLayer
@@ -131,13 +129,6 @@ def export_image(context, request, image_attr, caption_attr, **kw):
                 (context.absolute_url(),
                     getattr(context, image_attr).filename),
             'caption': getattr(context, caption_attr, None)}
-    config = getUtility(IAppConfig)
-    client_url = config.get("euphorie", {}).get("client")
-    if client_url:
-        client_url = client_url.rstrip('/')
-        old_base = request.client.absolute_url()
-        info['thumbnail'] = info['thumbnail'].replace(old_base, client_url)
-        info['original'] = info['original'].replace(old_base, client_url)
     return info
 
 
@@ -182,16 +173,17 @@ class JsonView(grok.View):
         if self.check_update and \
             wasSurveyUpdated(self.request.survey_session, self.request.survey):
             url = '%s/update' % self.request.survey_session.absolute_url()
-            return {'type': 'update',
-                    'next-step': url}
+            self.response.setHeader('Content-Type', 'application/json')
+            return json.dumps(
+                    {'type': 'update',
+                     'next-step': url})
 
         input = self.request.stdin.getvalue()
         if input:
             try:
                 self.input = json.loads(input)
             except ValueError:
-                self.response.setHeader(
-                        'Content-Type', 'application/json')
+                self.response.setHeader('Content-Type', 'application/json')
                 return json.dumps({'type': 'error',
                                    'message': 'Invalid JSON input'})
 
@@ -204,7 +196,7 @@ class JsonView(grok.View):
         renderer = getattr(self, 'do_%s' % method, None)
         if renderer is None:
             log.info('Invalid HTTP method %s attempted for %s',
-                    method, '.'.join(self.context.getPhysicalPath()))
+                    method, '/'.join(self.context.getPhysicalPath()))
             self.response.setStatus(405)
             response = {'type': 'error',
                         'message': 'HTTP method not allowed'}
