@@ -46,8 +46,9 @@ class PathGhost(OFS.Traversable.Traversable, Acquisition.Implicit):
     ZODB or SQL databsae exists.
     """
 
-    def __init__(self, id):
-        self.id=id
+    def __init__(self, id, request=None):
+        self.id = id
+        self.request = request
 
     def getId(self):
         return self.id
@@ -82,19 +83,16 @@ class View(grok.View):
                  if session.zodb_path==my_path]
 
 
-
     def _NewSurvey(self, info):
         """Utility method to start a new survey session."""
-        survey=aq_inner(self.context)
-        title=info.get("title", u"").strip()
+        survey = aq_inner(self.context)
+        title = info.get("title", u"").strip()
         if not title:
-            title=survey.Title()
-
+            title = survey.Title()
         SessionManager.start(title=title, survey=survey)
         self.request.response.redirect("%s/start" % survey.absolute_url())
 
 
-
     def _ContinueSurvey(self, info):
         """Utility method to continue an existing session."""
         session=Session.query(model.SurveySession).get(info["session"])
@@ -355,6 +353,56 @@ class Status(grok.View):
 
 
 
+def find_sql_context(session_id, zodb_path):
+    """Find the closest SQL tree node for a candidate path.
+
+    The path has to be given as a list of path entries. The session
+    timestamp is only used as part of a cache key for this method.
+
+    The return value is the id of the SQL tree node. All consumed
+    entries will be removed from the zodb_path list.
+    """
+    # Pop all integer elements from the URL
+    path = ""
+    head = []
+    while zodb_path:
+        next = zodb_path.pop()
+        if len(next) > 3:
+            zodb_path.append(next)
+            break
+
+        try:
+            path += '%03d' % int(next)
+            head.append(next)
+        except ValueError:
+            zodb_path.append(next)
+            break
+
+    # Try and find a SQL tree node that matches our URL
+    query = Session.query(model.SurveyTreeItem.id).\
+            filter(model.SurveyTreeItem.session_id == session_id).\
+            filter(model.SurveyTreeItem.path == sql.bindparam('path'))
+    while path:
+        node = query.params(path=path).first()
+        if node is not None:
+            return node[0]
+        path = path[:-3]
+        zodb_path.append(head.pop())
+
+
+def build_tree_aq_chain(root, tree_id):
+    """Build an acquisition context for a tree node.
+    """
+    tail = Session.query(model.SurveyTreeItem).get(tree_id)
+    walker = root
+    path = tail.path
+    while len(path) > 3:
+        id = str(int(path[:3]))
+        path = path[3:]
+        walker = PathGhost(id).__of__(walker)
+    return tail.__of__(walker)
+
+
 class SurveyPublishTraverser(DefaultPublishTraverse):
     """Publish traverser to setup the survey skin layers.
 
@@ -368,60 +416,6 @@ class SurveyPublishTraverser(DefaultPublishTraverse):
                 actionplan=IActionPlanPhaseSkinLayer,
                 report=IReportPhaseSkinLayer)
 
-    def findSqlContext(self, session_id, session_timestamp, zodb_path):
-        """Find the closest SQL tree node for a candidate path.
-
-        The path has to be given as a list of path entries. The session
-        timestamp is only used as part of a cache key for this method.
-
-        The return value is the id of the SQL tree node. All consumed
-        entries will be removed from the zodb_path list.
-        """
-        # Pop all integer elements from the URL
-        path=""
-        head=[]
-        while zodb_path:
-            next=zodb_path.pop()
-            if len(next)>3:
-                zodb_path.append(next)
-                break
-
-            try:
-                path+="%03d" % int(next)
-                head.append(next)
-            except ValueError:
-                zodb_path.append(next)
-                break
-
-        # Try and find a SQL tree node that matches our URL
-        query=Session.query(model.SurveyTreeItem.id).\
-                filter(model.SurveyTreeItem.session_id==session_id).\
-                filter(model.SurveyTreeItem.path==sql.bindparam("path"))
-        while path:
-            node=query.params(path=path).first()
-            if node is not None:
-                return node[0]
-
-            path=path[:-3]
-            zodb_path.append(head.pop())
-
-
-
-    def setupContext(self, tree_id):
-        """Build an acquisition context for a tree node.
-        """
-        node=Session.query(model.SurveyTreeItem).get(tree_id)
-
-        tail=self.context
-        path=node.path
-        while len(path)>3:
-            id=str(int(path[:3]))
-            path=path[3:]
-            tail=PathGhost(id).__of__(tail)
-        
-        return node.__of__(tail)
-
-
     def hasValidSession(self, request):
         """Check if the user has an active session for the survey.
         """
@@ -446,7 +440,6 @@ class SurveyPublishTraverser(DefaultPublishTraverse):
         return True
 
 
-
     def publishTraverse(self, request, name):
         request.survey=self.context
         utils.setLanguage(request, self.context, self.context.language)
@@ -464,12 +457,12 @@ class SurveyPublishTraverser(DefaultPublishTraverse):
                          *directlyProvidedBy(request))
         self.context=PathGhost(name).__of__(self.context)
 
-        session=SessionManager.session
-        tree_id=self.findSqlContext(session.id, session.created, request["TraversalRequestNameStack"])
+        session = SessionManager.session
+        tree_id = find_sql_context(session.id,
+                request['TraversalRequestNameStack'])
         if tree_id is not None:
-            return self.setupContext(tree_id)
+            return build_tree_aq_chain(self.context, tree_id)
 
         # No SQL based traversal possible, return the existing context with the
         # new skin layer applied
         return self.context
-
